gedidb.L2ABeam
==============

.. currentmodule:: gedidb

.. autoclass:: L2ABeam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L2ABeam.__init__
      ~L2ABeam.apply_filter
      ~L2ABeam.build_virtual_dataset
      ~L2ABeam.clear
      ~L2ABeam.copy
      ~L2ABeam.create_dataset
      ~L2ABeam.create_dataset_like
      ~L2ABeam.create_group
      ~L2ABeam.create_virtual_dataset
      ~L2ABeam.get
      ~L2ABeam.items
      ~L2ABeam.keys
      ~L2ABeam.move
      ~L2ABeam.pop
      ~L2ABeam.popitem
      ~L2ABeam.require_dataset
      ~L2ABeam.require_group
      ~L2ABeam.setdefault
      ~L2ABeam.update
      ~L2ABeam.values
      ~L2ABeam.visit
      ~L2ABeam.visit_links
      ~L2ABeam.visititems
      ~L2ABeam.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L2ABeam.attrs
      ~L2ABeam.beam_type
      ~L2ABeam.field_mapper
      ~L2ABeam.file
      ~L2ABeam.id
      ~L2ABeam.main_data
      ~L2ABeam.n_shots
      ~L2ABeam.name
      ~L2ABeam.parent
      ~L2ABeam.ref
      ~L2ABeam.regionref
   
   